@@ -100,6 +100,7 @@
 #define   MCHelpSwS          "\n  s[<N>,v[-],e] Create solid archive"
 #define   MCHelpSwSm         "\n  s-            Disable solid archiving"
 #define   MCHelpSwSFX        "\n  sfx[name]     Create SFX archive"
+#define   MCHelpSwSI         "\n  si[name]      Read data from standard input (stdin)"
 #define   MCHelpSwT          "\n  t             Test files after archiving"
 #define   MCHelpSwTK         "\n  tk            Keep original archive time"
 #define   MCHelpSwTL         "\n  tl            Set archive time to latest file"
@@ -110,6 +111,7 @@
 #define   MCHelpSwTS         "\n  ts<m,c,a>[N]  Save or restore file time (modification, creation, access)"
 #define   MCHelpSwU          "\n  u             Update files"
 #define   MCHelpSwV          "\n  v             Create volumes with size autodetection or list all volumes"
+#define   MCHelpSwVUnr       "\n  v             List all volumes"
 #define   MCHelpSwVn         "\n  v<size>[k,b]  Create volumes with size=<size>*1000 [*1024, *1]"
 #define   MCHelpSwVD         "\n  vd            Erase disk contents before creating volume"
 #define   MCHelpSwVER        "\n  ver[n]        File version control"
@@ -328,3 +330,4 @@
 #define   MSHelpCmdE         "\n  -x      Extract from archive (default)" 
 #define   MSHelpCmdT         "\n  -t      Test archive files" 
 #define   MSHelpCmdV         "\n  -v      Verbosely list contents of archive" 
+#define   MMaxPathLimit      "\nTotal path and file name length must not exceed %d characters"
